rpoispp1 <- function(lambda=NULL,Lambda=NULL,LambdaInv=NULL,a,b,lmax=NULL,
                     medium=NULL,units=NULL) {
#
# Three cases:
# (1) lambda not suppled (whence Lambda must be) --- use transformation.
# (2) lambda supplied and is a numeric constant --- trivial.
# (3) lambda supplied and is a function --- use thinning.
#

if(is.null(lambda)) {
    crate <- 1
} else {
    if(is.numeric(lambda)) {
        crate <- 2
    } else crate <- 3
}
switch(EXPR=crate,
    { # Simulate via transformation.
        if(is.null(Lambda))
		stop("One of \"lambda\" or \"Lambda\" must be specified.\n")
	A <- Lambda(a)
	B <- Lambda(b)
	M <- rpois(1,B-A)
	Y <- runif(M,A,B)
	if(!is.null(LambdaInv)) {
		X <- LambdaInv(Y)
	} else {
		X <- numeric(M)
		for(i in 1:M) {
			X[i] <- uniroot(function(t,s){Lambda(t)-s},c(a,b),s=Y[i])$root
		}
	}
	pp1(X,a=a,b=b,medium=medium,units=units)
    },
    { # Do the triv thing.
	if(length(lambda) > 1 || lambda < 0)
		stop("A numeric \"lambda\" should be a non-negative scalar.\n")
	m <- rpois(1,lambda*(b-a))
	pp1(runif(m,a,b),a=a,b=b,medium=medium,units=units)
    },
    { # Simulate via thinning.
        if(!is.function(lambda))
            stop("When not a numeric constant, \"lambda\" must be a function.\n")
        if(is.null(lmax)) {
           lmax <- optimize(lambda,c(a,b),maximum=TRUE)$objective
           lmax <- lmax*(1+sqrt(.Machine$double.eps))
        }
        if(lmax <= 0)
            stop("Argument \"lmax\" must be positive.\n")
        m <- rpois(1,lmax*(b-a))
        y <- runif(m,a,b)
        u <- runif(m)
        p <- lambda(y)/lmax
        if(any(p < 0))
            stop("Argument \"lambda\" must be a non-negative valued function.\n")
        pp1(y[u<p],a=a,b=b,medium=medium,units=units)
    }
)
}
