\name{doLeg}
\alias{doLeg}
\title{
  Create Legendre polynomials.
}
\description{
  Create Legendre polynomials \emph{as functions} for use (when
  evaluated over the interval over which the pattern inquestion is
  observed) as covariates from which to predict the intensity of
  the process generating the pattern in question.
}
\usage{
  doLeg(J)
}
\arguments{
  \item{J}{
  The maximum degree of the Legendre polynomials to be created.
}
}
\value{
  A list, of length \code{J}, of functions with arguments \code{x},
  and \code{interval}.  The \code{j}-th entry of this list evaluates
  the Legendre polynomial of degree \code{j} at \code{(2*x - a -
  b)/(b-a)} where \code{a = interval[1]} and \code{b = interval[2]}.
  The argument \code{interval} represents the interval over which
  the point pattern in question is observed.  In effect this
  interval is mapped onto the interval [-1,1], the natural domain
  of Legendre polynomials, before evaluating the polynomials.

  Note that the Legendre polynomial of degree 0 (i.e. the constant
  function 1) is omitted from this list.
}
\references{
   \url{http://en.wikipedia.org/wiki/Legendre_polynomials}
}
\author{Rolf Turner
  \email{r.turner@auckland.ac.nz}
}

\examples{
  lp3 <- doLeg(3)
  lp3[[3]](42,c(10,120)) # The Legendre polynomial of degree 3
                         # evaluated at (2*42 - 130)/100 = -0.4181818,
                         # giving 0.4444478.
}

\keyword{ math }
