\name{intensHist}
\alias{intensHist}
\title{
  Plot a histogram on an intensity scale.
}
\description{
  Plot a histogram of the points of a one dimensional point pattern
  on the intensity scale.  Optionally overlay a plot of the (estimated)
  intensity.
}
\usage{
  intensHist(x, breaks = NULL, nclass = NULL, main = "", include.lowest = TRUE,
             right = TRUE, ylab = "Intensity", iFn = NULL, col.iFn = "black",
             lty.iFn = 1, xlim.iFn = "short", ...)
}
\arguments{
  \item{x}{
  A one dimensional point pattern (i.e. a realization of a one dimensional
  point process).  May be an object of class \code{pp1} or a numeric
  vector (which will be coerced to an object of class \code{pp1}).
}
  \item{breaks}{
  See \code{\link{hist}()}.
}
  \item{nclass}{
  See \code{\link{hist}()}.
}
  \item{main}{
  An overall title for the plot.
}
  \item{include.lowest}{
  See \code{\link{hist}()}.
}
  \item{right}{
  See \code{\link{hist}()}.
}
  \item{ylab}{
  A label for the \code{y}-axis.
}
  \item{iFn}{
  A function specifying an intensity, presumably that approximated
  by the histogram being plotted.  This function should have an
  attribute \code{ylim} which will used to determine the appropriate
  overall \code{y}-axis limits for the plot.  The graph of this
  function, if it is specified, will be overlaid on top of the
  histogram.
}
  \item{col.iFn}{
  The colour for the graph of the function \code{iFn}.
}
  \item{lty.iFn}{
  The line type for the graph of the function \code{iFn}.
}
  \item{xlim.iFn}{
  Either a character string (which should be either) \code{short}
  or \code{long}, or a numeric vector of length 2 (specifying
  an interval.  If \code{xlim.iFn=="short"} then the interval over
  which \code{iFn} is plotted is taken to be the range of the breaks
  of the histogram.  If \code{xlim.iFn=="long"} then the interval
  over which \code{iFn} is plotted is taken to be the \code{interval}
  attribute of \code{x}.  histogram.  If \code{xlim.iFn} is a numeric
  vector then this vector is assumed to specify the interval over which
  to plot \code{iFn}.  In all other cases an error is given.
}
  \item{\dots}{
  Other arguments passed to \code{\link{plot.histogram}()}.
}
}
\details{
  The function \code{iFn} would typically be the \code{iFn}
  attribute of the value of \code{ppm1}.
}
\value{
  None.  A plot is produced as a \dQuote{side effect}.
}
\author{Rolf Turner
  \email{r.turner@auckland.ac.nz}
}

\seealso{
 \code{\link{ppm1}()}, \code{\link{hist}()}, \code{\link{plot.histogram}()}
}
\examples{
  data(ogata)
  fit <- with(ogata,ppm1(shallow ~ .,Data=doLeg(5),qtype="q",stype=3,ndum=17))
  with(ogata,intensHist(shallow,iFn=attr(fit,"iFn"),iFn.col="red"))
}

\keyword{ hplot }
