\encoding{UTF-8}
\name{plot.pp1}
\alias{plot.pp1}
\title{
Plot a one-dimensional point pattern.
}
\description{
Plot the cumulative count function of a one dimensional point
pattern, i.e. a realization of a one dimensional point process.
}
\usage{
  \method{plot}{pp1}(x,add=FALSE,xlim=NULL,ylim=NULL,xlab=NULL,ylab=NULL,
                     lbl=NULL,medium=NULL,mdm.dflt=c("time","space","other"),
                     xsym=NULL,units=NULL,pch=20,rug=!add,rug.col=NULL,
                     main="",...)

}
\arguments{
  \item{x}{
  A one dimensional point pattern (i.e. an object of class
  \code{pp1}) or simply a numeric vector (which will be coerced to
  an object of class \code{pp1}).
}
  \item{add}{
  Logical scalar; should the plot be added to an existing plot?
}
  \item{xlim}{
  The \code{xlim} argument to \code{\link{plot.stepfun}()}.  Defaults
  to the interval attribute of \code{x}.
}
  \item{ylim}{
  The \code{ylim} argument to \code{\link{plot.stepfun}()}.  Defaults
  to \code{c(0,length(x))}.
}
  \item{xlab}{
  The label for the \code{x} axis.  See the discussion below.
}
  \item{ylab}{
  The label for the \code{y} axis.  See the discussion below.
}
  \item{lbl}{Character string; \dQuote{label}.  Forms part of
  the \code{x}-axis label.  If not specified (i.e. if \code{NULL})
  it is equal to the value of \code{medium} (or is equal to \dots
  if \code{medium} is \code{"other"}.  See the
  discussion below.
}
  \item{medium}{Character string.  Over what medium (time, space,
  or something else) are the points of the pattern observed?
  Used in labelling the axes.  See the discussion below.
}
  \item{mdm.dflt}{Character string. Default specification of
  \code{medium}.  This determines the value that \code{medium} takes
  if other specifications are \code{NULL}.  See the discussion below.
}
  \item{xsym}{Character string; \dQuote{\code{x}-symbol}.
  Specification of the symbol used to represent the dependent
  variable in the plot.  Used in labelling the axes.  See the
  discussion below.
}
  \item{units}{Character string specifying the units, in which
  the medium over which the pattern is observed, is measured.
  Used in labelling the axes.  See the discussion below.
}
  \item{pch}{
  The plotting symbol used to plot the points (by default a filled
  circular dot).
}
  \item{rug}{
  Logical scalar; should a rug (see \code{\link{rug}()}) be added
  to the plot?
}
  \item{rug.col}{Specification of the colour in which the rug (if
  there is one) should be plotted.  May be any one of the three
  kinds of R color specifications.  Defaults to \code{par("fg")}.
}
  \item{main}{
  A title for the plot.
}
  \item{\dots}{
  Addtional arguments to be passed to \code{plot.stepfun}.
}
}
\details{
  Plots the cummulative count function of the observed pattern.
}
\section{Discussion of axis labelling}{
  This function is very (perhaps unnecessarily) versatile in its
  capabilities for labelling the axes.  The arguments \code{medium},
  \code{mdm.dflt}, \code{lbl}, \code{xsym}, and \code{units} all
  relate (only) to axis labelling.

  The object (argument) \code{x} may have attributes \code{"medium"}
  and \code{units}. If argument \code{medium} is not specified
  (i.e.  is \code{NULL}) then \code{medium} is set equal to
  the \code{"medium"} attribute of \code{x}.  If this too is
  \code{NULL} then \code{medium} is set equal to code{"mdm.dflt"}.

  The string \code{lbl} forms the essential component of the
  \code{x}-axis label.  If not specified (is \code{NULL}) \code{lbl}
  defaults to the value of \code{medium} (or to \dots if the
  value of \code{medium} is \code{"other"}).

  If not specified, the argument \code{xsym} becomes \code{t} if
  the value of medium is \code{"time"}, \code{x} if the value of
  medium is \code{"distance"}, and is unspecified and unused if
  the value of medium is anything else.  (In such circumstances,
  if it is desired that there be an \dQuote{\code{x}-symbol}, then
  the user must specify this symbol via the \code{xsym} argument.
  If the value of \code{xsym} is specified, it is converted (if
  possible) to an object of class \code{"name"} to facilitate use
  of the conventions of \code{\link{plotmath}}.

  The value of \code{units} is taken to be the \code{"units"}
  attribute of \code{x} if this is not \code{NULL}, and otherwise is
  taken to be the value of the code{units} argument.  If \code{units}
  remains NULL, it is set equal to \code{""} (the empty string).
  Otherwise it is converted (if possible) to an object of
  class \code{"name"} to facilitate use of the conventions of
  \code{\link{plotmath}}.

  Most of the foregoing may be safely ignored, in most circumstances.
  The user will need to use the subtle aspects of the given rules
  only if she or he wishes, or has to be, fussy about the labelling
  of the axes.
}

\value{
  None.  A plot is produced as a side effect.
}
\author{Rolf Turner
  \email{r.turner@auckland.ac.nz}
}

\seealso{
\code{\link{pp1}()} \code{\link{as.pp1}()} \code{\link{plot.stepfun}()}
\code{\link{rug}()}
}
\examples{
# Ogata quakes.
plot(ogata$deep,main="The Ogata quakes data.")
plot(ogata$shallow,add=TRUE,col="red")
legend("topleft",pch=20,lty=1,col=c("black","red"),legend=c("deep","shallow"))

# Simulated example.
n <- rpois(1,42)
X0 <- runif(n)
X0 <- pp1(X0,a=0,b=1,units="milliseconds")
plot(X0,main="Simulated Example")

# A bunch of examples illustrating some of the possibilities for
# axis labelling.
X1 <- rpoispp1(21,a=10,b=12,units="seconds")
plot(X1)

X2 <- rpoispp1(21,a=10,b=12,units=NULL)
plot(X2,mdm.dflt="s",xsym="delta",units="mu")

X3 <- rpoispp1(lambda=function(x){10*exp(cos(x))},a=0,b=3*pi,lmax=27.2)
plot(X3,mdm.dflt="o",lbl="Who knows?")

X4 <- rpoispp1(Lambda=function(x){x + x^2 + 0.1*x^3},a=0,b=10,units="furlongs")
plot(X4,xsym="zeta",lbl="garden path")

X5 <- rpoispp1(Lambda=function(x){10*sqrt(x)},LambdaInv=function(x){x^2/100},
            medium="Highway 61",a=10,b=260)
plot(X5,units="leagues",xsym="weariness")

# Despite its versatility, plot.pp1() has its limitations.  E.g. suppose
# you want xlab to finish with the string "µ (microns)".  I cannot find a
# way to make plot.pp1() handle this.  Currently if you do
#    X6 <- rpoispp1(42,a=10,b=12)
#    plot(X6,mdm.dflt="s",xsym="delta",units="mu (microns)")
# you get the string "mu" where you wanted the Greek letter µ.
# To work around this, set xlab="" (rather than leaving it NULL),
# and then add on the x-axis label using title().  Note that the
# following procedure requires a bit of plotmath arcana:
X6 <- rpoispp1(42,a=10,b=12)
plot(X6,mdm.dflt="s",xsym="delta",xlab="")
title(xlab=bquote(paste("distance (",delta,") in ",mu," (microns)")))
title(main="Well roll me in honey ....")
}
\keyword{ hplot }
