\name{pp1}
\alias{pp1}
\title{
  Create a one dimensional point pattern.
}
\description{
  Create an object of class \code{pp1} representing a one dimensional
  point pattern, i.e. a realization of a one dimensional point
  process.
}
\usage{
  pp1(x, a = NULL, b = NULL, medium=NULL, units=NULL)
}
\arguments{
  \item{x}{
   A (numeric) vector of \dQuote{event} or \dQuote{arrival} times
   (or possibly of distances from a starting point).
}
  \item{a}{
   If not left \code{NULL}, \code{a} should be either a numeric scalar
   or a numeric vector of length 2 whose first entry is less than
   its second entry.
}
  \item{b}{
   If not left \code{NULL}, \code{b} should be either a numeric scalar
   or a numeric vector of length 2 whose first entry is less than
   its second entry.
}
  \item{medium}{Character string.  Over what medium (time, space,
  or something else) are the points of the pattern observed?
  Used in labelling the axes.  See the discussion below.
}
   \item{units}{
   A character string (such as "seconds" or "weeks" or "millennia",
   or "furlongs") specifying the units of time, or possibly distance
   in which \code{x} is measured.
}
}
\details{
   The arguments \code{a} and \code{b} represent the endpoints
   of the interval over which the point pattern was observed.
   That is \code{a} may be the interval (in which case \code{b}
   must \code{NULL}), or \code{b} may be the interval (in which
   case \code{a} must \code{NULL}), or \code{a} may be the left
   hand end point and \code{b} may be the right hand endpoint.
   If both \code{a} and \code{b} are left \code{NULL} the interval
   is taken to be the range of \code{x}.  (This is \bold{NOT}
   recommended practice.)

   If some values of \code{x} fall outsied of the interval determined
   by \code{a} and \code{b}, an error is given.

   The event times \code{x} are sorted into increasing order by
   this function.

   If \code{x} is not a numeric vector an error is given.
}
\value{
   An object of class \code{pp1}, that is a numeric vector sorted
   into increasing order and having attributes \code{interval}
   (as determined by arguments \code{a} and \code{b}, or in dire
   circumstances by the range of \code{x}) and \code{units} as
   given by the argument \code{units}.
}
\author{Rolf Turner
  \email{r.turner@auckland.ac.nz}
}

\seealso{
 \code{\link{as.pp1}()}
}

\examples{
 x <- runif(rpois(1,100),0,10)
 x <- pp1(x,c(0,10),units="seconds")
}
\keyword{ datagen }
