\name{rpoispp1}
\alias{rpoispp1}
\title{
  Simulate a one dimensional Poisson process
}
\description{
  Simulate a one dimensional Poisson process on a specfied interval.
  If the intensity of the process is not a numeric constant then
  either transformation or thinning may be used to effect the
  simulation.
}
\usage{
   rpoispp1(lambda = NULL, Lambda = NULL, LambdaInv = NULL, a, b,
           lmax = NULL, medium=NULL,units = NULL)
}
\arguments{
  \item{lambda}{
  Either a positive scalar or a function (returning non-negative values),
  specifying the intensity of the process to be simulated.  If \code{lambda}
  is a scalar then \code{lmax} (see below) is ignored.
}
  \item{Lambda}{
  A function specifying the antiderivative of the intensity of the
  process to be simulated, i.e. the cumulative intensity.  Should be
  an increasing function.  If \code{lambda} is supplied, then \code{Lambda}
  is ignored.
}
  \item{LambdaInv}{
  The inverse of the function \code{Lambda}.
}
  \item{a}{
  The left hand endpoint of the interval over which the process is
  to be simulated.
}
  \item{b}{
  The right hand endpoint of the interval over which the process is
  to be simulated.
}
  \item{lmax}{
  The maximum over the interval \eqn{[a,b]} of the intensity function
  \code{lambda()}
}
  \item{medium}{Character string specifying the medium in which
  the points of the simulated pattern are assumed to be observed.
  Usually this will be \code{"time"} or \code{"space"}, but there may
  be other possibilities, e.g. \code{"depth"} or \code{"altitude"}.)
}
  \item{units}{
  The units in which time (or distance) along the interval \eqn{[a,b]}
  is measured, e.g. \code{"seconds"}, or \code{"months"}, or \code{"inches"},
  or \code{"metres"}, or \code{"fathoms"}.
}
}
\details{
   If \code{lambda()} is not specified then \code{Lambda()}
   \emph{must} be specified, and the transformation method is used.
   In this case \code{lmax} is ignored.  If \code{LambdaInv()} is
   not specified then \dQuote{inversion} is effected numerically
   (using \code{\link{uniroot}()}).

   If the intensity \code{lambda()} \emph{is} specified then
   \code{Lambda()} is ignored).  In this case, if \code{lmax} is
   not a numeric constant, then the thinning method is used, and
   if \code{lmax} is
   not specified it is calculated by maximising \code{lambda()}
   over \eqn{[a,b]}, using \code{optimize()}.

   If the intensity \code{lambda()} is specified and is a numeric
   constant, then the simulation is straightforward.
}
\value{
   A one dimensional point pattern (an object of class \code{pp1}).
}
\author{Rolf Turner
  \email{r.turner@auckland.ac.nz}
}
\seealso{
 \code{\link{pp1}()}
}
\examples{
X1 <- rpoispp1(42,a=10,b=12,medium="time",units="seconds")
X2 <- rpoispp1(function(x){10*exp(cos(x))},a=0,b=3*pi)
X3 <- rpoispp1(Lambda=function(x){x + x^2 + 0.1*x^3},a=0,b=10,
               medium="space",units="furlongs")
X4 <- rpoispp1(Lambda=function(x){10*sqrt(x)},LambdaInv=function(x){x^2/100},
            a=10,b=260)
}
\keyword{ datagen }
