\name{rrnwl}
\alias{rrnwl}
\title{
  Simulate a Renewal Process
}
\description{
  Simulate a renewal process on a specified interval, given
  the distribution of the interarrival times.
}
\usage{
  rrnwl(a, b, rfun, nstart = 1, medium=NULL, units=NULL, ...)
}
\arguments{
  \item{a}{
  The left hand endpoint of the interval on which the renewal
  process is to be generated.
}
  \item{b}{
  The right hand endpoint of the interval on which the renewal
  process is to be generated.
}
  \item{rfun}{
  A function to generate i.i.d. variables from a specified (non-negative)
  distribution.
}
  \item{nstart}{
  A starting value for the number of events to generate.  The
  procedure is most efficient if this quantity is roughly equal to
  \code{(b - a)/mu} where \code{mu} is the expected value of the
  variates generated by \code{rfun()}.
}
  \item{medium}{Character string.  Over what medium (time, space,
  or something else) are the points of the pattern observed?
  May be used by \code{plot.pp1()} in labelling the axes.  See the
  discussion in \code{\link{plot.pp1}()}.
}
  \item{units}{
  A character string (such as "seconds" or "weeks" or "millennia",
  or "furlongs") specifying the units of time, or possibly distance
  in which \code{x} is measured.
}
  \item{\dots}{
  Auxilliary arguments passed to \code{rfun()}.
}
}
\value{
  An object of class \code{pp1} with interval attribute equal to
  \code{c(a,b)}, medium attribute equal to \code{medium}, and units
  attribute equal to \code{units}.
}
\references{
  Ross, Sheldon. \emph{Stochastic Processes}, second edition.
  John Wiley & Sons, New York, 1996.
}
\author{Rolf Turner
  \email{r.turner@auckland.ac.nz}
}

\seealso{
 \code{\link{pp1}()}
}
\examples{
# Absolute Gaussian increments.
X1 <- rrnwl(a=3,b=12,rfun=function(n,sd){abs(rnorm(n,0,sd=sd))},
            medium="time",nstart=100,sd=0.09*sqrt(pi/2))
# Exponential increments (i.e. Poisson process).
X2 <- rrnwl(a=0,b=42,rfun=rexp,medium="space",units="microns (mu)",
            nstart=210,rate=5)
# Gamma increments.
X3 <- rrnwl(a=2,b=8,medium="depth",units="fathoms",
            rfun=rgamma,nstart=42,shape=3,scale=1/21)
}

\keyword{ datagen }
